@@ -1,21 +1,21 @@
 package internal
 
 import (
-	"reflect"
 	"testing"
 
 	"gotest.tools/v3/assert"
 
 	"github.com/walles/moor/v2/internal/reader"
+	"github.com/walles/moor/v2/internal/textstyles"
 	"github.com/walles/moor/v2/twin"
 )
 
-func tokenize(input string) []twin.StyledRune {
+func tokenize(input string) []textstyles.CellWithMetadata {
 	line := reader.NewLine(input)
 	return line.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, nil, nil, nil).StyledRunes
 }
 
-func rowsToString(cellLines [][]twin.StyledRune) string {
+func rowsToString(cellLines []textstyles.CellWithMetadataSlice) string {
 	returnMe := ""
 	for _, cellLine := range cellLines {
 		lineString := ""
@@ -36,12 +36,23 @@ func assertWrap(t *testing.T, input string, widthInScreenCells int, wrappedLines
 	toWrap := tokenize(input)
 	actual := wrapLine(widthInScreenCells, toWrap)
 
-	expected := [][]twin.StyledRune{}
+	expected := []textstyles.CellWithMetadataSlice{}
 	for _, wrappedLine := range wrappedLines {
 		expected = append(expected, tokenize(wrappedLine))
 	}
 
-	if reflect.DeepEqual(actual, expected) {
+	equal := true
+	if len(actual) != len(expected) {
+		equal = false
+	} else {
+		for i := range actual {
+			if !actual[i].Equal(expected[i]) {
+				equal = false
+				break
+			}
+		}
+	}
+	if equal {
 		return
 	}
 
