@@ -1,6 +1,6 @@
 package internal
 
-import "github.com/walles/moor/twin"
+import "github.com/walles/moor/v2/twin"
 
 type PagerModeMark struct {
 	pager *Pager
@@ -36,6 +36,6 @@ func (m PagerModeMark) onKey(key twin.KeyCode) {
 }
 
 func (m PagerModeMark) onRune(char rune) {
-	m.pager.marks[char] = m.pager.scrollPosition
+	m.pager.bookmarks[char] = m.pager.scrollPosition
 	m.pager.mode = PagerModeViewing(m)
 }
