@@ -20,7 +20,7 @@ func TestHighlightedTokensWithManPageHeading(t *testing.T) {
 	}
 
 	line := NewLine(manPageHeading)
-	highlighted := line.HighlightedTokens(twin.StyleDefault, nil, nil, nil)
+	highlighted := line.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, nil, nil, nil)
 
 	assert.Equal(t, len(highlighted.StyledRunes), len(headingText))
 	for i, cell := range highlighted.StyledRunes {
