@@ -50,11 +50,12 @@ type scrollPositionCanonical struct {
 }
 
 func canonicalFromPager(pager *Pager) scrollPositionCanonical {
-	width, height := pager.screen.Size()
+	width, _ := pager.screen.Size()
+	height := pager.visibleHeight()
 	return scrollPositionCanonical{
 		width:           width,
 		height:          height,
-		showLineNumbers: pager.ShowLineNumbers,
+		showLineNumbers: pager.showLineNumbers,
 		showStatusBar:   pager.ShowStatusBar,
 		wrapLongLines:   pager.WrapLongLines,
 
@@ -87,6 +88,29 @@ func (sp scrollPosition) NextLine(scrollDistance int) scrollPosition {
 	}
 }
 
+func (p *Pager) ScrollPositionsEqual(a, b scrollPosition) bool {
+	a.internalDontTouch.canonicalize(p)
+	b.internalDontTouch.canonicalize(p)
+	if a.internalDontTouch.deltaScreenLines != b.internalDontTouch.deltaScreenLines {
+		return false
+	}
+
+	if (a.internalDontTouch.lineIndex == nil) != (b.internalDontTouch.lineIndex == nil) {
+		// One line index is nil, the other is not
+		return false
+	}
+
+	if a.internalDontTouch.lineIndex != nil && b.internalDontTouch.lineIndex != nil {
+		// Both line indexes are non-nil...
+		if *a.internalDontTouch.lineIndex != *b.internalDontTouch.lineIndex {
+			// ... but they point to different lines.
+			return false
+		}
+	}
+
+	return true
+}
+
 // Create a new position, scrolled to the given line number
 //
 //revive:disable-next-line:unexported-return
@@ -214,33 +238,6 @@ func (si *scrollPositionInternal) isCanonical(pager *Pager) bool {
 	return false
 }
 
-// Is the given position visible on screen?
-func (sp scrollPosition) isVisible(pager *Pager) bool {
-	if sp.internalDontTouch.deltaScreenLines < 0 {
-		panic(fmt.Errorf("Negative incoming deltaScreenLines: %#v", sp.internalDontTouch))
-	}
-
-	if sp.internalDontTouch.lineIndex.IsBefore(*pager.lineIndex()) {
-		// Line number too low, not visible
-		return false
-	}
-
-	lastVisiblePosition := pager.getLastVisiblePosition()
-	if sp.internalDontTouch.lineIndex.IsAfter(*lastVisiblePosition.lineIndex(pager)) {
-		// Line number too high, not visible
-		return false
-	}
-
-	// Line number is within range, now check the sub-line number
-
-	if sp.internalDontTouch.deltaScreenLines > lastVisiblePosition.deltaScreenLines(pager) {
-		// Sub-line-number too high, not visible
-		return false
-	}
-
-	return true
-}
-
 // Only to be called from the scrollPosition getters!!
 //
 // Canonicalize the scroll position vs the given pager. A canonical position can
@@ -313,14 +310,6 @@ func (p *Pager) deltaScreenLines() int {
 	return p.scrollPosition.internalDontTouch.deltaScreenLines
 }
 
-// Scroll this many screen lines before rendering
-//
-// Always >= 0.
-func (sp *scrollPosition) deltaScreenLines(pager *Pager) int {
-	sp.internalDontTouch.canonicalize(pager)
-	return sp.internalDontTouch.deltaScreenLines
-}
-
 func (p *Pager) scrollToEnd() {
 	inputLineCount := p.Reader().GetLineCount()
 	if inputLineCount == 0 {
@@ -356,7 +345,7 @@ func (p *Pager) isScrolledToEnd() bool {
 	}
 	lastInputLineIndex := *linemetadata.IndexFromLength(inputLineCount)
 
-	visibleLines, _ := p.renderLines()
+	visibleLines := p.renderLines().lines
 	lastVisibleLine := visibleLines[len(visibleLines)-1]
 	if lastVisibleLine.inputLineIndex != lastInputLineIndex {
 		// Last input line is not on the screen
@@ -376,12 +365,12 @@ func (p *Pager) isScrolledToEnd() bool {
 
 // Returns nil if there are no lines
 func (p *Pager) getLastVisiblePosition() *scrollPosition {
-	renderedLines, _ := p.renderLines()
-	if len(renderedLines) == 0 {
+	rendered := p.renderLines()
+	if len(rendered.lines) == 0 {
 		return nil
 	}
 
-	lastRenderedLine := renderedLines[len(renderedLines)-1]
+	lastRenderedLine := rendered.lines[len(rendered.lines)-1]
 	return &scrollPosition{
 		internalDontTouch: scrollPositionInternal{
 			name:             "Last Visible Position",
