@@ -21,6 +21,11 @@ var statusbarStyle = twin.StyleDefault.WithAttr(twin.AttrReverse)
 
 var plainTextStyle = twin.StyleDefault
 
+var searchHitStyle = twin.StyleDefault.WithAttr(twin.AttrReverse)
+
+// This can be nil
+var searchHitLineBackground *twin.Color
+
 func setStyle(updateMe *twin.Style, envVarName string, fallback *twin.Style) {
 	envValue := os.Getenv(envVarName)
 	if envValue == "" {
@@ -117,6 +122,22 @@ func consumeLessTermcapEnvs(terminalBackground *twin.Color, chromaStyle *chroma.
 	}
 }
 
+func getOppositeColor(base twin.Color) twin.Color {
+	if base == twin.ColorDefault {
+		panic("can't get opposite of default color")
+	}
+
+	white := twin.NewColor24Bit(255, 255, 255)
+	black := twin.NewColor24Bit(0, 0, 0)
+	if base.Distance(white) > base.Distance(black) {
+		// Foreground is far away from white, so pretend the background is white
+		return white
+	} else {
+		// Foreground is far away from black, so pretend the background is black
+		return black
+	}
+}
+
 func styleUI(terminalBackground *twin.Color, chromaStyle *chroma.Style, chromaFormatter *chroma.Formatter, statusbarOption StatusBarOption, withTerminalFg bool) {
 	if chromaStyle == nil || chromaFormatter == nil {
 		return
@@ -169,6 +190,60 @@ func styleUI(terminalBackground *twin.Color, chromaStyle *chroma.Style, chromaFo
 	} else {
 		panic(fmt.Sprint("Unrecognized status bar style: ", statusbarOption))
 	}
+
+	configureHighlighting(terminalBackground)
+}
+
+// Expects to be called from the end of styleUI(), since at that
+// point we should have all data we need to set up highlighting.
+func configureHighlighting(terminalBackground *twin.Color) {
+	if standoutStyle != nil {
+		searchHitStyle = *standoutStyle
+		log.Trace("Search hit style set from standout style: ", searchHitStyle)
+	} else {
+		log.Trace("Search hit style set to default: ", searchHitStyle)
+	}
+
+	// Figure out a line background that lies between plainTextStyle and searchHit
+	var plainBg twin.Color
+	if terminalBackground != nil {
+		plainBg = *terminalBackground
+	} else if plainTextStyle.HasAttr(twin.AttrReverse) {
+		plainBg = plainTextStyle.Foreground()
+	} else {
+		plainBg = plainTextStyle.Background()
+	}
+
+	hitBg := searchHitStyle.Background()
+	hitFg := searchHitStyle.Foreground()
+	if searchHitStyle.HasAttr(twin.AttrReverse) {
+		hitBg = searchHitStyle.Foreground()
+		hitFg = searchHitStyle.Background()
+	}
+	if hitBg == twin.ColorDefault && hitFg != twin.ColorDefault {
+		// Not knowing the hit background color will be a problem further down
+		// when we want to create a line background color for lines with search
+		// hits.
+		//
+		// But since we know the foreground color, we can cheat and pretend the
+		// background is as far away from the foreground as possible.
+		hitBg = getOppositeColor(hitFg)
+	}
+	if hitBg == twin.ColorDefault && terminalBackground != nil {
+		// Assume the hit background is the opposite of the terminal background
+		hitBg = getOppositeColor(*terminalBackground)
+	}
+
+	if plainBg != twin.ColorDefault && hitBg != twin.ColorDefault {
+		// We have two real colors. Mix them! I got to "0.2" by testing some
+		// numbers. 0.2 is visible but not too strong.
+		mixed := plainBg.Mix(hitBg, 0.2)
+		searchHitLineBackground = &mixed
+
+		log.Trace("Search hit line background set to mixed color: ", *searchHitLineBackground)
+	} else {
+		log.Debug("Cannot set search hit line background based on plainBg=", plainBg, " hitBg=", hitBg)
+	}
 }
 
 func TermcapToStyle(termcap string) (twin.Style, error) {
